@@ -1,5 +1,5 @@
-from singular.endpoints._bases import _Endpoint
-from singular.documents import *
+from singular_client.endpoints._bases import _Endpoint
+from singular_client.documents import *
 
 class GraphQL(_Endpoint[dict]):
     endpoint = "graphql/graphql"
