@@ -1,8 +1,8 @@
-from singular.endpoints._bases import _Endpoint, ResponseDocList
-from singular.documents import *
-from singular.arguments import *
+from singular_client.endpoints._bases import _Endpoint, ResponseDocList
+from singular_client.documents import *
+from singular_client.arguments import *
 from typing import *
-from singular._utils import *
+from singular_client._utils import *
 
 class AdMonetizationEndpoint(_Endpoint[ResponseDocList[AdMonetizationDoc]]):
     endpoint = "v2.0/admonetization/reporting"
